var get = require('lodash.get');
var cloneDeep = require('lodash.clonedeep');
var dateFns = require('date-fns');
var jsonSchemaToYup = require('json-schema-to-yup');
var isArray = require('lodash.isarray');
var tslib = require('tslib');
require('reflect-metadata');
var classValidator = require('class-validator');
var classTransformer = require('class-transformer');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var get__default = /*#__PURE__*/_interopDefaultLegacy(get);
var cloneDeep__default = /*#__PURE__*/_interopDefaultLegacy(cloneDeep);
var isArray__default = /*#__PURE__*/_interopDefaultLegacy(isArray);

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  _setPrototypeOf(subClass, superClass);
}
function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };
  return _setPrototypeOf(o, p);
}
function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}
function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}
function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;
  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
  return arr2;
}
function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);
  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

// Desc: Configs for the translation that is used in the validation messages
var translatesConfig = {
  nullable: 'generic-form:validation.nullable',
  required: 'generic-form:validation.required',
  min: 'generic-form:validation.min',
  max: 'generic-form:validation.max',
  maxLength: 'generic-form:validation.max_length',
  minLength: 'generic-form:validation.min_length',
  pattern: 'generic-form:validation.pattern',
  format: 'generic-form:validation.format',
  email: 'generic-form:validation.email',
  minDate: 'generic-form:validation.min_date',
  maxDate: 'generic-form:validation.max_date',
  wrongRange: 'generic-form:validation.wrong_range',
  wrongDate: 'generic-form:validation.wrong_range',
  trim: 'generic-form:validation.trim',
  oneOf: 'generic-form:validation.one_of'
};
// Desc: Enum for the validation error types
var EValidationTypes;
(function (EValidationTypes) {
  EValidationTypes["nullable"] = "nullable";
  EValidationTypes["required"] = "required";
  EValidationTypes["min"] = "min";
  EValidationTypes["max"] = "max";
  EValidationTypes["oneOf"] = "oneOf";
  EValidationTypes["maxLength"] = "maxLength";
  EValidationTypes["minLength"] = "minLength";
  EValidationTypes["pattern"] = "pattern";
  EValidationTypes["format"] = "format";
  EValidationTypes["minDate"] = "minDate";
  EValidationTypes["maxDate"] = "maxDate";
  EValidationTypes["wrongRange"] = "wrongRange";
  EValidationTypes["wrongDate"] = "wrongDate";
  EValidationTypes["trim"] = "trim";
})(EValidationTypes || (EValidationTypes = {}));

exports.EFieldTypes = void 0;
(function (EFieldTypes) {
  EFieldTypes["TEXT"] = "text";
  EFieldTypes["NUMBER"] = "number";
  EFieldTypes["SWITCH"] = "switch";
  EFieldTypes["DATE"] = "date";
  EFieldTypes["DATE_RANGE"] = "dateRange";
  EFieldTypes["AUTOCOMPLETE"] = "autoComplete";
  EFieldTypes["FILE"] = "file";
  EFieldTypes["ARRAY"] = "array";
  EFieldTypes["MOBILE_PHONE"] = "mobilePhone";
  EFieldTypes["MULTIPLE_AUTOCOMPLETE"] = "autoCompleteMultiple";
  EFieldTypes["RADIOBUTTON"] = "radioButton";
  EFieldTypes["YES_NO_RADIOBUTTON"] = "yesNoRadioButton";
  EFieldTypes["EMPTY"] = "empty";
  EFieldTypes["CHECKBOX"] = "checkbox";
  EFieldTypes["RADIOBUTTON_MATRIX"] = "radioButtonMatrix";
  EFieldTypes["RATING"] = "rating";
})(exports.EFieldTypes || (exports.EFieldTypes = {}));
exports.ESelectTypes = void 0;
(function (ESelectTypes) {
  ESelectTypes["COUNTRIES"] = "countries";
  ESelectTypes["RELATIONSHIP"] = "relationship";
})(exports.ESelectTypes || (exports.ESelectTypes = {}));

/**
 * @param formDataChildren - array of form fields
 * @param formSettings
 * @param acc - accumulator, used for recursion
 * @returns {[key: string]: any} - object with the initial values for the form
 * @description getInitialValues function returns an object with the initial values for the form
 * based on the initial values provided in the json schema
 */

function _catch(body, recover) {
  try {
    var result = body();
  } catch (e) {
    return recover(e);
  }
  if (result && result.then) {
    return result.then(void 0, recover);
  }
  return result;
} /**
   * @param schema - yup schema
   * @param fieldName - field name to get the rule value from
   * @param ruleName - rule name to get the value from
   * @returns {any} - rule value
   * @description getRuleValueFromSchema function returns the value of a rule from a yup schema
   * based on the field name and rule name. This value is needed for passing meta to translations.
   * @example getRuleValueFromSchema(schema, 'email', 'minLength') => 6
   */
var getInitialValues = function getInitialValues(formDataChildren, formSettings, acc) {
  if (acc === void 0) {
    acc = {};
  }
  return formDataChildren.reduce(function (acc, item) {
    if (isFormGroup(item)) {
      return getInitialValues(item.children, formSettings, acc);
    }
    var overridesObject = get__default["default"](formSettings, String(item.fieldName) + ".overrides", {});
    var initialValue = Object.keys(overridesObject).includes('initialValue') ? overridesObject.initialValue : item.initialValue;
    acc[item.fieldName] = initialValue;
    return acc;
  }, acc);
};
var getRuleValueFromSchema = function getRuleValueFromSchema(schema, fieldName, ruleName) {
  var describedSchema = schema.describe();
  var rules = get__default["default"](describedSchema, "fields." + fieldName + ".tests", []);
  var rule = rules.find(function (rule) {
    return rule.name === ruleName;
  });
  return get__default["default"](rule, "params." + ruleName, undefined);
};
/**
 * @param type - validation type
 * @param value - value to be validated
 * @param t - translation function(optional)
 * @param validationParam - validation param(meta) to be passed to the translation function(optional) or error object
 * @returns {any} - error object or function, or translated string
 * @description getFieldError function returns an error object or function, or translated string based on the validation type
 */
var getFieldError = function getFieldError(type, value, t, validationParam) {
  var translationKey = get__default["default"](translatesConfig, "" + type);
  switch (type) {
    case EValidationTypes.nullable:
      return t ? t(translationKey) : createErrorObject(translationKey);
    case EValidationTypes.required:
      return t ? t(translationKey) : createErrorObject(translationKey);
    case EValidationTypes.min:
      return t ? function (_ref) {
        var min = _ref.min;
        return t(translationKey, {
          param: min
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.max:
      return t ? function (_ref2) {
        var max = _ref2.max;
        return t(translationKey, {
          param: max
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.maxLength:
      return t ? function (_ref3) {
        var maxLength = _ref3.maxLength;
        return t(translationKey, {
          param: maxLength
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.minLength:
      return t ? function (_ref4) {
        var minLength = _ref4.minLength;
        return t(translationKey, {
          param: minLength
        });
      } : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.format:
      if (value) {
        translationKey = get__default["default"](translatesConfig, "" + type) ? get__default["default"](translatesConfig, "" + type) : translationKey;
      }
      return t ? t(translationKey) : createErrorObject(translationKey, {
        param: validationParam
      });
    case EValidationTypes.trim:
    case EValidationTypes.oneOf:
    case EValidationTypes.pattern:
      return t ? t(translationKey) : createErrorObject(translationKey, {
        param: validationParam
      });
    default:
      return null;
  }
};
/**
 * @param validationObject
 * @param formValues - form values to be validated
 * @returns {IValidationErrors} - object with the validation errors
 * @description makeCrossFieldValidation function makes custom cross-field validation
 * and returns an object with the validation errors
 */
var makeCrossFieldValidation = function makeCrossFieldValidation(validationObject, formValues) {
  var errors = {};
  try {
    var keys = Object.keys(validationObject);
    keys.forEach(function (fieldName) {
      var rules = validationObject[fieldName];
      var fieldErrors = {
        property: fieldName,
        constraints: {}
      };
      rules == null || rules.forEach(function (rule, id) {
        var errorKey = rule.errorKey,
          testCondition = rule.testCondition,
          meta = rule.meta;
        var testFunction = functionFromString(testCondition);
        var shouldIncludeError = false;
        try {
          shouldIncludeError = testFunction(formValues);
        } catch (e) {
          console.log('Error during evaluating custom validation rule. This issue wont cause an error, current validation was skipped', e);
        }
        if (shouldIncludeError) {
          fieldErrors.constraints[id] = createErrorObject(errorKey, meta);
        }
      });
      if (Object.keys(fieldErrors.constraints).length > 0) {
        errors[fieldName] = fieldErrors;
      }
    });
    return errors;
  } catch (e) {
    console.warn('Error in makeCrossFieldValidation: ', e);
    return {};
  }
};
/**
 * @param fieldName - field name
 * @param values - form values
 * @param errors - object with the validation errors
 * @returns {IValidationErrors} - object with the validation errors
 * @description validateDateRangeField function validates date range field
 * and returns an object with the validation errors
 */
var validateDateRangeField = function validateDateRangeField(fieldName, values, errors) {
  if (errors === void 0) {
    errors = {};
  }
  var minDate = dateFns.subYears(new Date(), 100);
  var maxDate = dateFns.addYears(new Date(), 100);
  var error = {
    property: fieldName,
    constraints: {}
  };
  var dateRangeUnmapped = get__default["default"](values, fieldName, [null, null]);
  if (!isArray__default["default"](dateRangeUnmapped)) {
    error.constraints[EValidationTypes.wrongDate] = {
      translationKey: translatesConfig[EValidationTypes.wrongDate],
      fallbackLanguageTranslation: 'This field expected to be array of strings',
      meta: {}
    };
    if (!errors[fieldName]) {
      errors[fieldName] = error;
    } else {
      errors[fieldName].constraints = _extends({}, errors[fieldName].constraints, error.constraints);
    }
    return errors;
  }
  if (dateRangeUnmapped[0] === null && dateRangeUnmapped[1] === null) {
    return errors;
  }
  var dateRange = dateRangeUnmapped.map(function (value) {
    return value ? dateFns.parse(value, 'yyyy-MM-dd', new Date()) : null;
  });
  if (!dateFns.isValid(dateRange[0]) || !dateFns.isValid(dateRange[1])) {
    error.constraints[EValidationTypes.wrongDate] = {
      translationKey: translatesConfig[EValidationTypes.wrongDate],
      fallbackLanguageTranslation: 'Some date in range is invalid',
      meta: {}
    };
  }
  if (!dateRange[0] || !dateRange[1]) {
    error.constraints[EValidationTypes.required] = {
      translationKey: translatesConfig[EValidationTypes.required],
      fallbackLanguageTranslation: 'Some date in range is empty',
      meta: {}
    };
  }
  if (dateRange[0] && dateFns.isBefore(dateRange[0], minDate) || dateRange[1] && dateFns.isBefore(dateRange[1], minDate)) {
    error.constraints[EValidationTypes.minDate] = {
      translationKey: translatesConfig[EValidationTypes.minDate],
      fallbackLanguageTranslation: 'Date range should be between 100 years ago and 100 years in the future',
      meta: {}
    };
  }
  if (dateRange[1] && dateFns.isAfter(dateRange[1], maxDate) || dateRange[0] && dateFns.isAfter(dateRange[0], maxDate)) {
    error.constraints[EValidationTypes.maxDate] = {
      translationKey: translatesConfig[EValidationTypes.maxDate],
      fallbackLanguageTranslation: 'Date range should be between 100 years ago and 100 years in the future',
      meta: {}
    };
  }
  if (dateRange[0] && dateRange[1] && (dateFns.isAfter(dateRange[0], dateRange[1]) || dateFns.isEqual(dateRange[0], dateRange[1]))) {
    error.constraints[EValidationTypes.wrongRange] = {
      translationKey: translatesConfig[EValidationTypes.wrongRange],
      fallbackLanguageTranslation: 'Start date should be before end date',
      meta: {}
    };
  }
  if (Object.keys(error.constraints).length > 0) {
    if (!errors[fieldName]) {
      errors[fieldName] = error;
    } else {
      errors[fieldName].constraints = _extends({}, errors[fieldName].constraints, error.constraints);
    }
  }
  return errors;
};
/**
 * @param jsonSchema - json validation schema
 * @param t - translation function(optional)
 * @returns {AnyObjectSchema} - yup validation schema
 * @description buildYupSchema function builds a yup validation schema based on the json validation schema
 */
var buildYupSchema = function buildYupSchema(jsonSchema, t) {
  return jsonSchemaToYup.buildYup(cloneDeep__default["default"](jsonSchema), t ? {
    errMessages: getErrorMessages(jsonSchema, t)
  } : undefined);
};
/**
 * @param form {IForm} - form json schema
 * @param valuesToValidate {any} - form values to be validated
 * @param skipCrossField {boolean} - skip cross-field validation(optional)
 * @returns {Promise<unknown>} - object with the validation errors or error that has occurred during the validation
 * @description validateValues function validates the form values based on the json form object
 */
var validateValues = function validateValues(_ref5, valuesToValidate, skipCrossField) {
  var children = _ref5.children,
    jsonSchema = _ref5.jsonSchema,
    formSettings = _ref5.formSettings;
  if (skipCrossField === void 0) {
    skipCrossField = false;
  }
  try {
    var _temp2 = function _temp2(_result) {
      return _exit ? _result : {
        errors: Object.values(errors)
      };
    };
    var _exit;
    var errors = {};
    var flattenedValues = flattenValues(cloneDeep__default["default"](valuesToValidate));
    var trimmedValues = trimValuesInObject(flattenedValues);
    var _temp = _catch(function () {
      var validationSchema = buildYupSchema(jsonSchema);
      var dateRangeFields = getFieldNamesByType(children, exports.EFieldTypes.DATE_RANGE);
      if (!skipCrossField) {
        var formFieldNames = Object.keys(formSettings);
        var crossFieldValidations = formFieldNames.reduce(function (acc, el) {
          if (!formSettings[el].crossFieldValidations) {
            return acc;
          }
          acc[el] = formSettings[el].crossFieldValidations;
          return acc;
        }, {});
        errors = makeCrossFieldValidation(crossFieldValidations, trimmedValues);
      }
      if (dateRangeFields.length > 0) {
        dateRangeFields.forEach(function (fieldName) {
          errors = validateDateRangeField(fieldName, trimmedValues, errors);
        });
      }
      return Promise.resolve(validationSchema.validate(trimmedValues, {
        abortEarly: false
      })).then(function () {});
    }, function (e) {
      if (get__default["default"](e, 'name') === 'ValidationError') {
        errors = formatYupValidationErrors(e, errors);
      } else {
        throw e;
      }
    });
    return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
  } catch (e) {
    return Promise.reject(e);
  }
};

var _excluded = ["grid", "renderCondition", "disabledCondition"],
  _excluded2 = ["crossFieldValidations"];
var buildOptionsFromChildren = function buildOptionsFromChildren(children, formOptions) {
  if (formOptions === void 0) {
    formOptions = {};
  }
  return children.reduce(function (acc, child) {
    if (isFormGroup(child)) {
      return buildOptionsFromChildren(child.children, acc);
    }
    var fieldLayout = child.grid || {
      md: 12,
      sm: 12,
      xs: 12
    };
    var crossFieldConditions = {};
    if (child.renderCondition) {
      crossFieldConditions.renderCondition = child.renderCondition;
    }
    if (child.disabledCondition) {
      crossFieldConditions.disabledCondition = child.disabledCondition;
    }
    var setting = {
      fieldLayout: fieldLayout
    };
    if (crossFieldConditions != null && crossFieldConditions.disabledCondition || crossFieldConditions != null && crossFieldConditions.renderCondition) {
      setting.crossFieldConditions = crossFieldConditions;
    }
    acc[child.fieldName] = setting;
    return acc;
  }, formOptions);
};
var sanitizeChildrenFunction = function sanitizeChildrenFunction(children) {
  return children.map(function (child) {
    if (isFormGroup(child)) {
      return _extends({}, child, {
        children: sanitizeChildrenFunction(child.children)
      });
    }
    var sanitizedChild = _objectWithoutPropertiesLoose(child, _excluded);
    return sanitizedChild;
  });
};
var parseFormV1 = function parseFormV1(form) {
  var submitButtonText = form.submitButtonText,
    cancelButtonText = form.cancelButtonText,
    _form$validationObjec = form.validationObject,
    crossFieldValidations = _form$validationObjec.crossFieldValidations,
    sanitizedValidationObject = _objectWithoutPropertiesLoose(_form$validationObjec, _excluded2),
    children = form.children;
  var formOptions = buildOptionsFromChildren(children);
  var fieldsWithCrossFieldValidations = Object.keys(crossFieldValidations);
  fieldsWithCrossFieldValidations.forEach(function (key) {
    formOptions[key].crossFieldValidations = crossFieldValidations[key];
  });
  var sanitizedChildren = sanitizeChildrenFunction(children);
  var parsedForm = {
    formatVersion: 'parsed',
    jsonSchema: sanitizedValidationObject,
    formSettings: formOptions,
    children: sanitizedChildren,
    submitButtonText: submitButtonText
  };
  if (cancelButtonText) {
    parsedForm.cancelButtonText = cancelButtonText;
  }
  return parsedForm;
};

var parseFormV2 = function parseFormV2(form) {
  var submitButtonText = form.submitButtonText,
    cancelButtonText = form.cancelButtonText,
    validationObject = form.validationObject,
    crossFieldValidations = form.crossFieldValidations,
    crossFieldConditions = form.crossFieldConditions,
    formLayout = form.formLayout,
    overrides = form.overrides,
    children = form.children;
  var allFieldNames = Object.keys(validationObject.properties);
  var formOptions = allFieldNames.reduce(function (acc, fieldName) {
    var fieldLayout = formLayout[fieldName] || {
      md: 12,
      sm: 12,
      xs: 12
    };
    var formSetting = {
      fieldLayout: fieldLayout
    };
    if (crossFieldValidations != null && crossFieldValidations[fieldName]) {
      formSetting.crossFieldValidations = crossFieldValidations[fieldName];
    }
    if (crossFieldConditions != null && crossFieldConditions[fieldName]) {
      formSetting.crossFieldConditions = crossFieldConditions == null ? void 0 : crossFieldConditions[fieldName];
    }
    if (overrides != null && overrides[fieldName]) {
      formSetting.overrides = overrides[fieldName];
    }
    acc[fieldName] = formSetting;
    return acc;
  }, {});
  var parsedForm = {
    formatVersion: 'parsed',
    jsonSchema: validationObject,
    formSettings: formOptions,
    children: children,
    submitButtonText: submitButtonText
  };
  if (cancelButtonText) {
    parsedForm.cancelButtonText = cancelButtonText;
  }
  return parsedForm;
};
var parseToFormV2 = function parseToFormV2(form) {
  var submitButtonText = form.submitButtonText,
    cancelButtonText = form.cancelButtonText,
    formSettings = form.formSettings,
    jsonSchema = form.jsonSchema,
    children = form.children;
  var allFieldNames = Object.keys(formSettings);
  var crossFieldValidations = {};
  var crossFieldConditions = {};
  var formLayout = {};
  var overrides = {};
  allFieldNames.forEach(function (key) {
    var _formSettings$key, _formSettings$key2, _formSettings$key3, _formSettings$key4;
    var keyCrossFieldConditions = (_formSettings$key = formSettings[key]) == null ? void 0 : _formSettings$key.crossFieldConditions;
    var keyCrossFieldValidations = (_formSettings$key2 = formSettings[key]) == null ? void 0 : _formSettings$key2.crossFieldValidations;
    var keyFieldOverrides = (_formSettings$key3 = formSettings[key]) == null ? void 0 : _formSettings$key3.overrides;
    if (keyCrossFieldConditions) {
      crossFieldConditions[key] = keyCrossFieldConditions;
    }
    if (keyCrossFieldValidations) {
      crossFieldValidations[key] = keyCrossFieldValidations;
    }
    if (keyFieldOverrides) {
      overrides[key] = keyFieldOverrides;
    }
    formLayout[key] = ((_formSettings$key4 = formSettings[key]) == null ? void 0 : _formSettings$key4.fieldLayout) || {
      md: 12,
      sm: 12,
      xs: 12
    };
  });
  var formV2 = {
    formatVersion: 2,
    crossFieldConditions: crossFieldConditions,
    crossFieldValidations: crossFieldValidations,
    formLayout: formLayout,
    overrides: overrides,
    validationObject: jsonSchema,
    children: children,
    submitButtonText: submitButtonText
  };
  if (cancelButtonText) {
    formV2.cancelButtonText = cancelButtonText;
  }
  return formV2;
};

/**
 * @param jsonSchema - jsonSchema validation object
 * @param t - i18n translate function
 * @returns {any}
 * @description getErrorMessages function returns an object with the error messages for each field in the form based on the jsonSchema
 */
var getErrorMessages = function getErrorMessages(jsonSchema, t) {
  var errMessages = {};
  Object.keys(jsonSchema.properties).forEach(function (property) {
    errMessages[property] = {};
    Object.keys(jsonSchema.properties[property]).forEach(function (key) {
      var value = jsonSchema.properties[property][key];
      errMessages[property][key] = getFieldError(key, value, t);
      if (Object.keys(jsonSchema).includes(key)) {
        errMessages[property].required = getFieldError('required', null, t);
      }
    });
  });
  return errMessages;
};
/**
 * @param translateKey
 * @param param
 * @returns {IValidationError}
 * @description createErrorObject function returns an object with the error message
 * for a field in the form in a proper format
 * @example createErrorObject('required', { param: 'email' }) => { translationKey: 'required', fallbackLanguageTranslation: 'This field is required', meta: { param: 'email' } }
 */
var createErrorObject = function createErrorObject(translateKey, param) {
  return {
    translationKey: translateKey,
    fallbackLanguageTranslation: translateKey,
    meta: param || {}
  };
};
function isFormGroup(toBeDetermined) {
  return !!toBeDetermined.children;
}
/**
 * @param stringifiedFunction
 * @returns {Function}
 * @description functionFromString returns a function from a stringified function
 * @example functionFromString('/Function((values) => {return values.medicalConditions.toString() === 'true'})/')
 * => (values) => values.medicalConditions.toString() === 'true'
 */
var functionFromString = function functionFromString(stringifiedFunction) {
  try {
    var substr = stringifiedFunction.substring(10, stringifiedFunction.length - 2);
    return (0, eval)('(' + substr + ')');
  } catch (e) {
    console.log('Error parsing custom validation function in functionFromString. This issue wont cause an error, current validation was skipped', e);
    return function () {
      return false;
    };
  }
};
/**
 * @param validationError - yup validation error
 * @param initialErrors - initial errors object to be merged with the yup validation errors
 * @returns {IValidationErrors} - returns an object with the errors for each field in the form
 * @description formatYupValidationErrors function returns an object with the errors for each field in the form
 * based on the yup validation error formatting to be used in the GenericForm component
 * @example formatYupValidationErrors(yupValidationError, { email: { property: 'email', constraints: { required: { translationKey: 'required', fallbackLanguageTranslation: 'This field is required', meta: {} } } } })
 */
var formatYupValidationErrors = function formatYupValidationErrors(validationError, initialErrors) {
  if (initialErrors === void 0) {
    initialErrors = {};
  }
  var errors = _extends({}, initialErrors);
  for (var _iterator = _createForOfIteratorHelperLoose(validationError.inner), _step; !(_step = _iterator()).done;) {
    var _propertyValidationEr;
    var propertyValidationError = _step.value;
    var errorType = propertyValidationError.type;
    if (!errorType && (_propertyValidationEr = propertyValidationError.params) != null && _propertyValidationEr.regex) {
      var _propertyValidationEr2;
      if (!((_propertyValidationEr2 = propertyValidationError.params) != null && _propertyValidationEr2.regex)) {
        continue;
      }
      errorType = 'pattern';
    }
    if (!get__default["default"](errors, "" + propertyValidationError.path)) {
      errors[propertyValidationError.path] = {
        property: propertyValidationError.path,
        constraints: {}
      };
    }
    errors[propertyValidationError.path].constraints[errorType] = _extends({}, getFieldError(errorType, get__default["default"](propertyValidationError, 'path', null), undefined, get__default["default"](propertyValidationError.params, "" + propertyValidationError.type)), {
      fallbackLanguageTranslation: propertyValidationError.message
    });
  }
  return errors;
};
/**
 * @param children
 * @param type - field type
 * @param acc - accumulator, used for recursion
 * @returns {string[]} - array of field names
 * @description getFieldNamesByType function returns an array of field names based on the field type
 * @example getFieldNamesByType(form, EFieldTypes.TEXT) => ['firstName', 'lastName']
 */
var getFieldNamesByType = function getFieldNamesByType(children, type, acc) {
  if (acc === void 0) {
    acc = [];
  }
  return children.reduce(function (acc, child) {
    if (isFormGroup(child)) {
      return getFieldNamesByType(child.children, type, acc);
    }
    if (child.type === type) {
      acc.push(child.fieldName);
    }
    return acc;
  }, acc);
};
var getAllFieldNames = function getAllFieldNames(children, acc) {
  if (acc === void 0) {
    acc = [];
  }
  return children.reduce(function (acc, child) {
    if (isFormGroup(child)) {
      return getAllFieldNames(child.children, acc);
    }
    acc.push(child.fieldName);
    return acc;
  }, acc);
};
var flattenValues = function flattenValues(obj) {
  var flattenedValues = cloneDeep__default["default"](obj);
  var keys = Object.keys(obj);
  keys.forEach(function (k) {
    if (typeof obj[k] === 'object' && Object.prototype.propertyIsEnumerable.call(obj[k], 'value')) {
      flattenedValues[k] = obj[k].value;
    }
  });
  return flattenedValues;
};
var valuesToDBFormat = function valuesToDBFormat(obj) {
  var dbValues = cloneDeep__default["default"](obj);
  var keys = Object.keys(obj);
  keys.forEach(function (k) {
    var dbObject = {};
    Object.defineProperty(dbObject, 'value', {
      enumerable: true,
      value: obj[k]
    });
    dbValues[k] = dbObject;
  });
  return dbValues;
};
/**
 * @param obj - object to trim
 * @returns {any} - object with trimmed values
 * @description trimValuesInObject function returns an object with trimmed values
 */
var trimValuesInObject = function trimValuesInObject(obj) {
  var trimmedValues = _extends({}, obj);
  var keys = Object.keys(obj);
  keys.forEach(function (k) {
    return obj[k] = typeof obj[k] == 'string' ? trimmedValues[k] = String(obj[k]).trim() : trimmedValues[k] = obj[k];
  });
  return trimmedValues;
};
var parseForm = function parseForm(form) {
  if (!(form != null && form.formatVersion)) {
    throw new Error('formatVersion is required');
  }
  switch (form.formatVersion) {
    case 1:
      return parseFormV1(form);
    case 2:
      return parseFormV2(form);
    default:
      throw new Error('The parsing function for this version of forms is not implemented');
  }
};

function IsInValidProperties(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'IsInValidProperties',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          return validProperties.includes(value);
        },
        defaultMessage: function defaultMessage(args) {
          return args.property + " must be included in " + validProperties.join(', ') + ".";
        }
      }
    });
  };
}

function IsCrossFieldValidations(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'isArrayOfType',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          for (var key in value) {
            if (!Array.isArray(value[key])) {
              return false;
            }
            for (var _iterator = _createForOfIteratorHelperLoose(args.value[key]), _step; !(_step = _iterator()).done;) {
              var item = _step.value;
              if (typeof item.errorKey !== 'string' || typeof item.testCondition !== 'string' || item.meta !== undefined && typeof item.meta.param !== 'number') {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          var invalidIndexes = [];
          var invalidInstances = [];
          for (var key in args.value) {
            if (!Array.isArray(args.value[key])) {
              invalidIndexes.push(key);
            } else {
              for (var _iterator2 = _createForOfIteratorHelperLoose(args.value[key]), _step2; !(_step2 = _iterator2()).done;) {
                var item = _step2.value;
                if (typeof item.errorKey !== 'string' || typeof item.testCondition !== 'string' || item.meta !== undefined && typeof item.meta.param !== 'number') {
                  invalidInstances.push(key);
                }
              }
            }
          }
          var message = args.property + " must be an array";
          if (invalidIndexes.length > 0) {
            var indexesString = invalidIndexes.join(', ');
            message += "." + indexesString;
          }
          if (invalidInstances.length > 0) {
            var instancesString = invalidInstances.join(', ');
            message += " and " + instancesString + " must be instances of CrossFieldValidationRule";
          }
          return message;
        }
      }
    });
  };
}

function isJsonSchemaPropertyValid(property) {
  if (property.id === undefined || typeof property.id !== 'number') {
    return false;
  }
  if (property.maxLength !== undefined && typeof property.maxLength !== 'number') {
    return false;
  }
  if (property.minLength !== undefined && typeof property.minLength !== 'number') {
    return false;
  }
  if (property.pattern !== undefined && typeof property.pattern !== 'string') {
    return false;
  }
  if (property.items !== undefined) {
    var items = property.items;
    if (typeof items !== 'object' || items.type !== 'string' || items.format !== 'date' || typeof items.minLength !== 'number' || typeof items.required !== 'boolean') {
      return false;
    }
  }
  return true;
}
function IsJsonSchemaProperty(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'isJsonSchemaProperty',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          if (typeof value !== 'object') {
            return false;
          }
          for (var key in value) {
            var property = value[key];
            if (property !== null && typeof property === 'object') {
              if (!isJsonSchemaPropertyValid(property)) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          return args.property + " must be a valid IJsonSchemaProperty object.";
        }
      }
    });
  };
}

function isCrossFieldConditionsParamsValid(params) {
  if (params.required && typeof params.required !== 'string') {
    return false;
  }
  if (params.disabled && typeof params.disabled !== 'string') {
    return false;
  }
  if (params.renderCondition && typeof params.renderCondition !== 'string') {
    return false;
  }
  if (params.disabledCondition && typeof params.disabledCondition !== 'string') {
    return false;
  }
  return true;
}
function IsCrossFieldConditions(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'isCrossFieldConditions',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          if (typeof value !== 'object') {
            return false;
          }
          for (var key in value) {
            if (!isCrossFieldConditionsParamsValid(value[key])) {
              return false;
            }
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          return args.property + " must be a valid ICrossFieldConditions object.";
        }
      }
    });
  };
}

function isFormOverridesValid(override) {
  if (override.fieldTitle !== undefined && typeof override.fieldTitle !== 'string') {
    return false;
  }
  if (override.fieldSubtitle !== undefined && override.fieldSubtitle !== null && typeof override.fieldSubtitle !== 'string') {
    return false;
  }
  if (override.options !== undefined && !Array.isArray(override.options)) {
    return false;
  }
  if (override.placeholder !== undefined && typeof override.placeholder !== 'string') {
    return false;
  }
  if (override.helperText !== undefined && typeof override.helperText !== 'string') {
    return false;
  }
  return true;
}
function IsFormOverrides(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'isFormOverrides',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          if (typeof value !== 'object') {
            return false;
          }
          for (var key in value) {
            var override = value[key];
            if (override !== null && typeof override === 'object') {
              if (!isFormOverridesValid(override)) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          return args.property + " must be a valid IFormOverrides object.";
        }
      }
    });
  };
}

function IsFormLayout(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'isFormLayout',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          if (typeof value !== 'object') {
            return false;
          }
          for (var key in value) {
            var breakpoints = value[key];
            if (breakpoints !== null && typeof breakpoints === 'object') {
              if (!isRegularBreakpointsValid(breakpoints)) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          return args.property + " must be a valid IFormLayout object.";
        }
      }
    });
  };
}
function isRegularBreakpointsValid(breakpoints) {
  var validGridSizes = [1, 2, 3, 4, 6, 8, 10, 12, 'auto', undefined];
  for (var key in breakpoints) {
    if (!['lg', 'md', 'sm', 'xl', 'xs'].includes(key)) {
      return false;
    }
    var gridSize = breakpoints[key];
    if (!validGridSizes.includes(gridSize)) {
      return false;
    }
  }
  return true;
}

var IsEqualToConstraint = /*#__PURE__*/function () {
  function IsEqualToConstraint() {}
  var _proto = IsEqualToConstraint.prototype;
  _proto.validate = function validate(value, args) {
    var _args$constraints = args.constraints,
      comparisonValue = _args$constraints[0];
    return value === comparisonValue;
  };
  _proto.defaultMessage = function defaultMessage(args) {
    return args.property + " must be equal to " + args.constraints[0];
  };
  return IsEqualToConstraint;
}();
IsEqualToConstraint = tslib.__decorate([classValidator.ValidatorConstraint({
  name: 'isEqualTo',
  async: false
})], IsEqualToConstraint);
function IsEqualTo(comparisonValue, validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      constraints: [comparisonValue],
      validator: IsEqualToConstraint
    });
  };
}

function IsKeysValid(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'IsKeysValid',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          if (typeof value !== 'object') {
            return false;
          }
          for (var key in value) {
            if (!validProperties.includes(key)) {
              return false;
            }
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          return "Keys of " + args.property + " must be in [" + validProperties.join(', ') + "]";
        }
      }
    });
  };
}

function IsFieldNameValid(validationOptions) {
  return function (object, propertyName) {
    classValidator.registerDecorator({
      name: 'IsFieldNameValid',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate: function validate(value, args) {
          if (!validProperties.includes(args.value)) {
            return false;
          }
          return true;
        },
        defaultMessage: function defaultMessage(args) {
          return "Value of " + args.property + " must be in [" + validProperties.join(', ') + "]";
        }
      }
    });
  };
}

var validProperties = [];
var Option = function Option() {
  this.id = void 0;
  this.label = void 0;
  this.value = void 0;
};
tslib.__decorate([classValidator.IsNumber()], Option.prototype, "id", void 0);
tslib.__decorate([classValidator.IsString()], Option.prototype, "label", void 0);
var JsonSchema = function JsonSchema() {
  this.$schema = void 0;
  this.title = void 0;
  this.description = void 0;
  this.type = void 0;
  this.properties = void 0;
  this.required = void 0;
};
tslib.__decorate([classValidator.IsString(), classValidator.IsNotEmpty()], JsonSchema.prototype, "$schema", void 0);
tslib.__decorate([classValidator.IsString(), classValidator.IsNotEmpty()], JsonSchema.prototype, "title", void 0);
tslib.__decorate([classValidator.IsString(), classValidator.IsNotEmpty()], JsonSchema.prototype, "description", void 0);
tslib.__decorate([classValidator.IsString(), classValidator.IsNotEmpty()], JsonSchema.prototype, "type", void 0);
tslib.__decorate([IsJsonSchemaProperty()], JsonSchema.prototype, "properties", void 0);
tslib.__decorate([classValidator.IsArray(), IsInValidProperties({
  each: true
})], JsonSchema.prototype, "required", void 0);
var CrossFieldValidationRule = function CrossFieldValidationRule(obj) {
  this.errorKey = void 0;
  this.testCondition = void 0;
  this.meta = void 0;
  this.errorKey = obj.errorKey;
  this.meta = obj.meta;
  this.testCondition = obj.testCondition;
};
tslib.__decorate([classValidator.IsString({
  message: 'errorKey must be a string.'
}), classValidator.IsNotEmpty({
  message: 'errorKey is required.'
})], CrossFieldValidationRule.prototype, "errorKey", void 0);
tslib.__decorate([classValidator.IsString({
  message: 'testCondition must be a string.'
}), classValidator.IsNotEmpty({
  message: 'testCondition is required.'
})], CrossFieldValidationRule.prototype, "testCondition", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsObject({
  message: 'meta must be an object.'
}), classValidator.ValidateNested()], CrossFieldValidationRule.prototype, "meta", void 0);
var CommonChildrenFull = function CommonChildrenFull() {
  this.type = exports.EFieldTypes.EMPTY;
  this.fieldName = '';
  this.initialValue = '';
  this.templateId = '';
  this.fieldTitle = void 0;
  this.fieldSubtitle = void 0;
  this.placeholder = void 0;
};
tslib.__decorate([classValidator.IsEnum(exports.EFieldTypes)], CommonChildrenFull.prototype, "type", void 0);
tslib.__decorate([classValidator.IsString(), classValidator.Matches(/^[a-zA-Z$_][a-zA-Z0-9$_]*$/, {
  message: 'fieldName must start with a letter, dollar sign, or underscore, and may only contain letters, digits, dollar signs, and underscores.'
}), classValidator.MaxLength(30), IsFieldNameValid()], CommonChildrenFull.prototype, "fieldName", void 0);
tslib.__decorate([classValidator.IsString()], CommonChildrenFull.prototype, "templateId", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsString()], CommonChildrenFull.prototype, "fieldTitle", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsString()], CommonChildrenFull.prototype, "fieldSubtitle", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsString()], CommonChildrenFull.prototype, "placeholder", void 0);
var ChildrenTextFull = /*#__PURE__*/function (_CommonChildrenFull) {
  _inheritsLoose(ChildrenTextFull, _CommonChildrenFull);
  function ChildrenTextFull() {
    var _this;
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    _this = _CommonChildrenFull.call.apply(_CommonChildrenFull, [this].concat(args)) || this;
    _this.multiline = void 0;
    _this.maxLength = void 0;
    _this.type = exports.EFieldTypes.TEXT;
    _this.initialValue = null;
    _this.disabled = void 0;
    return _this;
  }
  return ChildrenTextFull;
}(CommonChildrenFull);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsBoolean()], ChildrenTextFull.prototype, "multiline", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsString()], ChildrenTextFull.prototype, "maxLength", void 0);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.TEXT)], ChildrenTextFull.prototype, "type", void 0);
tslib.__decorate([IsEqualTo(null)], ChildrenTextFull.prototype, "initialValue", void 0);
var ChildrenAutoCompleteFull = /*#__PURE__*/function (_CommonChildrenFull2) {
  _inheritsLoose(ChildrenAutoCompleteFull, _CommonChildrenFull2);
  function ChildrenAutoCompleteFull() {
    var _this2;
    for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
      args[_key2] = arguments[_key2];
    }
    _this2 = _CommonChildrenFull2.call.apply(_CommonChildrenFull2, [this].concat(args)) || this;
    _this2.backendOptions = void 0;
    _this2.backendSelectType = void 0;
    _this2.options = void 0;
    _this2.disabledOptionIds = void 0;
    _this2.type = exports.EFieldTypes.AUTOCOMPLETE;
    _this2.initialValue = null;
    _this2.loading = void 0;
    _this2.disabled = void 0;
    return _this2;
  }
  return ChildrenAutoCompleteFull;
}(CommonChildrenFull);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsBoolean()], ChildrenAutoCompleteFull.prototype, "backendOptions", void 0);
tslib.__decorate([classValidator.IsEnum(exports.ESelectTypes), classValidator.IsOptional()], ChildrenAutoCompleteFull.prototype, "backendSelectType", void 0);
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function () {
  return Option;
})], ChildrenAutoCompleteFull.prototype, "options", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsArray()], ChildrenAutoCompleteFull.prototype, "disabledOptionIds", void 0);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.AUTOCOMPLETE)], ChildrenAutoCompleteFull.prototype, "type", void 0);
tslib.__decorate([IsEqualTo(null)], ChildrenAutoCompleteFull.prototype, "initialValue", void 0);
tslib.__decorate([classValidator.IsBoolean(), classValidator.IsOptional()], ChildrenAutoCompleteFull.prototype, "loading", void 0);
tslib.__decorate([classValidator.IsBoolean(), classValidator.IsOptional()], ChildrenAutoCompleteFull.prototype, "disabled", void 0);
var ChildrenMobilePhoneFull = /*#__PURE__*/function (_CommonChildrenFull3) {
  _inheritsLoose(ChildrenMobilePhoneFull, _CommonChildrenFull3);
  function ChildrenMobilePhoneFull() {
    var _this3;
    for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
      args[_key3] = arguments[_key3];
    }
    _this3 = _CommonChildrenFull3.call.apply(_CommonChildrenFull3, [this].concat(args)) || this;
    _this3.type = exports.EFieldTypes.MOBILE_PHONE;
    _this3.initialValue = '';
    _this3.maxLength = void 0;
    return _this3;
  }
  return ChildrenMobilePhoneFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.MOBILE_PHONE)], ChildrenMobilePhoneFull.prototype, "type", void 0);
tslib.__decorate([classValidator.IsString()], ChildrenMobilePhoneFull.prototype, "initialValue", void 0);
tslib.__decorate([classValidator.IsString(), classValidator.IsOptional()], ChildrenMobilePhoneFull.prototype, "maxLength", void 0);
var ChildrenRadioButtonFull = /*#__PURE__*/function (_CommonChildrenFull4) {
  _inheritsLoose(ChildrenRadioButtonFull, _CommonChildrenFull4);
  function ChildrenRadioButtonFull() {
    var _this4;
    for (var _len4 = arguments.length, args = new Array(_len4), _key4 = 0; _key4 < _len4; _key4++) {
      args[_key4] = arguments[_key4];
    }
    _this4 = _CommonChildrenFull4.call.apply(_CommonChildrenFull4, [this].concat(args)) || this;
    _this4.type = exports.EFieldTypes.RADIOBUTTON;
    _this4.initialValue = null;
    _this4.options = void 0;
    return _this4;
  }
  return ChildrenRadioButtonFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.RADIOBUTTON)], ChildrenRadioButtonFull.prototype, "type", void 0);
tslib.__decorate([IsEqualTo(null)], ChildrenRadioButtonFull.prototype, "initialValue", void 0);
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function () {
  return Option;
})], ChildrenRadioButtonFull.prototype, "options", void 0);
var ChildrenCheckboxFull = /*#__PURE__*/function (_CommonChildrenFull5) {
  _inheritsLoose(ChildrenCheckboxFull, _CommonChildrenFull5);
  function ChildrenCheckboxFull() {
    var _this5;
    for (var _len5 = arguments.length, args = new Array(_len5), _key5 = 0; _key5 < _len5; _key5++) {
      args[_key5] = arguments[_key5];
    }
    _this5 = _CommonChildrenFull5.call.apply(_CommonChildrenFull5, [this].concat(args)) || this;
    _this5.type = exports.EFieldTypes.CHECKBOX;
    _this5.placeholder = '';
    _this5.initialValue = false;
    return _this5;
  }
  return ChildrenCheckboxFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.CHECKBOX)], ChildrenCheckboxFull.prototype, "type", void 0);
tslib.__decorate([classValidator.IsString()], ChildrenCheckboxFull.prototype, "placeholder", void 0);
tslib.__decorate([classValidator.IsBoolean(), IsEqualTo(false)], ChildrenCheckboxFull.prototype, "initialValue", void 0);
var ChildrenNumberFul = /*#__PURE__*/function (_CommonChildrenFull6) {
  _inheritsLoose(ChildrenNumberFul, _CommonChildrenFull6);
  function ChildrenNumberFul() {
    var _this6;
    for (var _len6 = arguments.length, args = new Array(_len6), _key6 = 0; _key6 < _len6; _key6++) {
      args[_key6] = arguments[_key6];
    }
    _this6 = _CommonChildrenFull6.call.apply(_CommonChildrenFull6, [this].concat(args)) || this;
    _this6.type = exports.EFieldTypes.NUMBER;
    _this6.initialValue = 0;
    return _this6;
  }
  return ChildrenNumberFul;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.NUMBER)], ChildrenNumberFul.prototype, "type", void 0);
tslib.__decorate([classValidator.IsNumber()], ChildrenNumberFul.prototype, "initialValue", void 0);
var ChildrenDateFull = /*#__PURE__*/function (_CommonChildrenFull7) {
  _inheritsLoose(ChildrenDateFull, _CommonChildrenFull7);
  function ChildrenDateFull() {
    var _this7;
    for (var _len7 = arguments.length, args = new Array(_len7), _key7 = 0; _key7 < _len7; _key7++) {
      args[_key7] = arguments[_key7];
    }
    _this7 = _CommonChildrenFull7.call.apply(_CommonChildrenFull7, [this].concat(args)) || this;
    _this7.disableFuture = void 0;
    _this7.disablePast = void 0;
    _this7.minDate = void 0;
    _this7.helperText = '';
    _this7.type = exports.EFieldTypes.DATE;
    _this7.initialValue = null;
    return _this7;
  }
  return ChildrenDateFull;
}(CommonChildrenFull);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsBoolean()], ChildrenDateFull.prototype, "disableFuture", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsBoolean()], ChildrenDateFull.prototype, "disablePast", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsDateString()], ChildrenDateFull.prototype, "minDate", void 0);
tslib.__decorate([classValidator.IsNotEmpty()], ChildrenDateFull.prototype, "helperText", void 0);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.DATE)], ChildrenDateFull.prototype, "type", void 0);
var ChildrenDateRangeFull = /*#__PURE__*/function (_CommonChildrenFull8) {
  _inheritsLoose(ChildrenDateRangeFull, _CommonChildrenFull8);
  function ChildrenDateRangeFull() {
    var _this8;
    for (var _len8 = arguments.length, args = new Array(_len8), _key8 = 0; _key8 < _len8; _key8++) {
      args[_key8] = arguments[_key8];
    }
    _this8 = _CommonChildrenFull8.call.apply(_CommonChildrenFull8, [this].concat(args)) || this;
    _this8.type = exports.EFieldTypes.DATE_RANGE;
    _this8.initialValue = [null, null];
    _this8.disableFuture = void 0;
    _this8.disablePast = void 0;
    _this8.minDate = void 0;
    _this8.helperText = '';
    return _this8;
  }
  return ChildrenDateRangeFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.DATE_RANGE)], ChildrenDateRangeFull.prototype, "type", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsBoolean()], ChildrenDateRangeFull.prototype, "disableFuture", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsBoolean()], ChildrenDateRangeFull.prototype, "disablePast", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsISO8601()], ChildrenDateRangeFull.prototype, "minDate", void 0);
tslib.__decorate([classValidator.IsString()], ChildrenDateRangeFull.prototype, "helperText", void 0);
var ChildrenFileFull = /*#__PURE__*/function (_CommonChildrenFull9) {
  _inheritsLoose(ChildrenFileFull, _CommonChildrenFull9);
  function ChildrenFileFull() {
    var _this9;
    for (var _len9 = arguments.length, args = new Array(_len9), _key9 = 0; _key9 < _len9; _key9++) {
      args[_key9] = arguments[_key9];
    }
    _this9 = _CommonChildrenFull9.call.apply(_CommonChildrenFull9, [this].concat(args)) || this;
    _this9.type = exports.EFieldTypes.FILE;
    return _this9;
  }
  return ChildrenFileFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.FILE)], ChildrenFileFull.prototype, "type", void 0);
var ChildrenMultipleAutocompleteFull = /*#__PURE__*/function (_CommonChildrenFull10) {
  _inheritsLoose(ChildrenMultipleAutocompleteFull, _CommonChildrenFull10);
  function ChildrenMultipleAutocompleteFull() {
    var _this10;
    for (var _len10 = arguments.length, args = new Array(_len10), _key10 = 0; _key10 < _len10; _key10++) {
      args[_key10] = arguments[_key10];
    }
    _this10 = _CommonChildrenFull10.call.apply(_CommonChildrenFull10, [this].concat(args)) || this;
    _this10.type = exports.EFieldTypes.MULTIPLE_AUTOCOMPLETE;
    return _this10;
  }
  return ChildrenMultipleAutocompleteFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.MULTIPLE_AUTOCOMPLETE)], ChildrenMultipleAutocompleteFull.prototype, "type", void 0);
var ChildrenArrayFull = /*#__PURE__*/function (_CommonChildrenFull11) {
  _inheritsLoose(ChildrenArrayFull, _CommonChildrenFull11);
  function ChildrenArrayFull() {
    var _this11;
    for (var _len11 = arguments.length, args = new Array(_len11), _key11 = 0; _key11 < _len11; _key11++) {
      args[_key11] = arguments[_key11];
    }
    _this11 = _CommonChildrenFull11.call.apply(_CommonChildrenFull11, [this].concat(args)) || this;
    _this11.type = exports.EFieldTypes.ARRAY;
    return _this11;
  }
  return ChildrenArrayFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.ARRAY)], ChildrenArrayFull.prototype, "type", void 0);
var RegularBreakpoints = function RegularBreakpoints() {
  this.lg = void 0;
  this.md = void 0;
  this.sm = void 0;
  this.xl = void 0;
  this.xs = void 0;
};
tslib.__decorate([classValidator.IsOptional(), classValidator.IsIn(['auto', 1, 2, 3, 4, 6, 8, 10, 12])], RegularBreakpoints.prototype, "lg", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsIn(['auto', 1, 2, 3, 4, 6, 8, 10, 12])], RegularBreakpoints.prototype, "md", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsIn(['auto', 1, 2, 3, 4, 6, 8, 10, 12])], RegularBreakpoints.prototype, "sm", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsIn(['auto', 1, 2, 3, 4, 6, 8, 10, 12])], RegularBreakpoints.prototype, "xl", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsIn(['auto', 1, 2, 3, 4, 6, 8, 10, 12])], RegularBreakpoints.prototype, "xs", void 0);
var RadioButtonMatrixOptions = function RadioButtonMatrixOptions() {
  this.rows = void 0;
  this.columns = void 0;
  this.grid = void 0;
};
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function () {
  return Option;
})], RadioButtonMatrixOptions.prototype, "rows", void 0);
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function () {
  return Option;
})], RadioButtonMatrixOptions.prototype, "columns", void 0);
tslib.__decorate([classTransformer.Type(function () {
  return RegularBreakpoints;
})], RadioButtonMatrixOptions.prototype, "grid", void 0);
var ChildrenRadioButtonMatrixFull = /*#__PURE__*/function (_CommonChildrenFull12) {
  _inheritsLoose(ChildrenRadioButtonMatrixFull, _CommonChildrenFull12);
  function ChildrenRadioButtonMatrixFull() {
    var _this12;
    for (var _len12 = arguments.length, args = new Array(_len12), _key12 = 0; _key12 < _len12; _key12++) {
      args[_key12] = arguments[_key12];
    }
    _this12 = _CommonChildrenFull12.call.apply(_CommonChildrenFull12, [this].concat(args)) || this;
    _this12.type = exports.EFieldTypes.RADIOBUTTON_MATRIX;
    _this12.radioButtonMatrixOptions = void 0;
    return _this12;
  }
  return ChildrenRadioButtonMatrixFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.RADIOBUTTON_MATRIX)], ChildrenRadioButtonMatrixFull.prototype, "type", void 0);
tslib.__decorate([classTransformer.Type(function () {
  return RadioButtonMatrixOptions;
})], ChildrenRadioButtonMatrixFull.prototype, "radioButtonMatrixOptions", void 0);
var ChildrenEmptyFull = /*#__PURE__*/function (_CommonChildrenFull13) {
  _inheritsLoose(ChildrenEmptyFull, _CommonChildrenFull13);
  function ChildrenEmptyFull() {
    var _this13;
    for (var _len13 = arguments.length, args = new Array(_len13), _key13 = 0; _key13 < _len13; _key13++) {
      args[_key13] = arguments[_key13];
    }
    _this13 = _CommonChildrenFull13.call.apply(_CommonChildrenFull13, [this].concat(args)) || this;
    _this13.type = exports.EFieldTypes.EMPTY;
    return _this13;
  }
  return ChildrenEmptyFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.EMPTY)], ChildrenEmptyFull.prototype, "type", void 0);
var ChildrenSwitchFull = /*#__PURE__*/function (_CommonChildrenFull14) {
  _inheritsLoose(ChildrenSwitchFull, _CommonChildrenFull14);
  function ChildrenSwitchFull() {
    var _this14;
    for (var _len14 = arguments.length, args = new Array(_len14), _key14 = 0; _key14 < _len14; _key14++) {
      args[_key14] = arguments[_key14];
    }
    _this14 = _CommonChildrenFull14.call.apply(_CommonChildrenFull14, [this].concat(args)) || this;
    _this14.type = exports.EFieldTypes.SWITCH;
    return _this14;
  }
  return ChildrenSwitchFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.SWITCH)], ChildrenSwitchFull.prototype, "type", void 0);
var ChildrenYesNoRadioButtonFull = /*#__PURE__*/function (_CommonChildrenFull15) {
  _inheritsLoose(ChildrenYesNoRadioButtonFull, _CommonChildrenFull15);
  function ChildrenYesNoRadioButtonFull() {
    var _this15;
    for (var _len15 = arguments.length, args = new Array(_len15), _key15 = 0; _key15 < _len15; _key15++) {
      args[_key15] = arguments[_key15];
    }
    _this15 = _CommonChildrenFull15.call.apply(_CommonChildrenFull15, [this].concat(args)) || this;
    _this15.type = exports.EFieldTypes.YES_NO_RADIOBUTTON;
    _this15.options = void 0;
    _this15.initialValue = null;
    return _this15;
  }
  return ChildrenYesNoRadioButtonFull;
}(CommonChildrenFull);
tslib.__decorate([IsEqualTo(exports.EFieldTypes.YES_NO_RADIOBUTTON)], ChildrenYesNoRadioButtonFull.prototype, "type", void 0);
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function () {
  return Option;
})], ChildrenYesNoRadioButtonFull.prototype, "options", void 0);
tslib.__decorate([IsEqualTo(null)], ChildrenYesNoRadioButtonFull.prototype, "initialValue", void 0);
var FormGroupFull = function FormGroupFull() {
  this.title = void 0;
  this.subtitle = void 0;
  this.children = void 0;
};
tslib.__decorate([classValidator.IsString(), classValidator.IsOptional()], FormGroupFull.prototype, "title", void 0);
tslib.__decorate([classValidator.IsString(), classValidator.IsOptional()], FormGroupFull.prototype, "subtitle", void 0);
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function (prop) {
  if (prop) {
    var _prop$object, _prop$object2, _prop$object3, _prop$object4, _prop$object5, _prop$object6, _prop$object7, _prop$object8, _prop$object9, _prop$object10, _prop$object11, _prop$object12, _prop$object13, _prop$object14, _prop$object15;
    if (((_prop$object = prop.object) == null ? void 0 : _prop$object.type) === exports.EFieldTypes.TEXT) {
      return ChildrenTextFull;
    }
    if (((_prop$object2 = prop.object) == null ? void 0 : _prop$object2.type) === exports.EFieldTypes.AUTOCOMPLETE) {
      return ChildrenAutoCompleteFull;
    }
    if (((_prop$object3 = prop.object) == null ? void 0 : _prop$object3.type) === exports.EFieldTypes.DATE) {
      return ChildrenDateFull;
    }
    if (((_prop$object4 = prop.object) == null ? void 0 : _prop$object4.type) === exports.EFieldTypes.RADIOBUTTON) {
      return ChildrenRadioButtonFull;
    }
    if (((_prop$object5 = prop.object) == null ? void 0 : _prop$object5.type) === exports.EFieldTypes.CHECKBOX) {
      return ChildrenCheckboxFull;
    }
    if (((_prop$object6 = prop.object) == null ? void 0 : _prop$object6.type) === exports.EFieldTypes.NUMBER) {
      return ChildrenNumberFul;
    }
    if (((_prop$object7 = prop.object) == null ? void 0 : _prop$object7.type) === exports.EFieldTypes.MOBILE_PHONE) {
      return ChildrenMobilePhoneFull;
    }
    if (((_prop$object8 = prop.object) == null ? void 0 : _prop$object8.type) === exports.EFieldTypes.DATE_RANGE) {
      return ChildrenDateRangeFull;
    }
    if (((_prop$object9 = prop.object) == null ? void 0 : _prop$object9.type) === exports.EFieldTypes.FILE) {
      return ChildrenFileFull;
    }
    if (((_prop$object10 = prop.object) == null ? void 0 : _prop$object10.type) === exports.EFieldTypes.MULTIPLE_AUTOCOMPLETE) {
      return ChildrenMultipleAutocompleteFull;
    }
    if (((_prop$object11 = prop.object) == null ? void 0 : _prop$object11.type) === exports.EFieldTypes.ARRAY) {
      return ChildrenArrayFull;
    }
    if (((_prop$object12 = prop.object) == null ? void 0 : _prop$object12.type) === exports.EFieldTypes.RADIOBUTTON_MATRIX) {
      return ChildrenRadioButtonMatrixFull;
    }
    if (((_prop$object13 = prop.object) == null ? void 0 : _prop$object13.type) === exports.EFieldTypes.EMPTY) {
      return ChildrenEmptyFull;
    }
    if (((_prop$object14 = prop.object) == null ? void 0 : _prop$object14.type) === exports.EFieldTypes.SWITCH) {
      return ChildrenSwitchFull;
    }
    if (((_prop$object15 = prop.object) == null ? void 0 : _prop$object15.type) === exports.EFieldTypes.YES_NO_RADIOBUTTON) {
      return ChildrenYesNoRadioButtonFull;
    }
  }
  return Object;
}, {
  discriminator: {
    property: 'type',
    subTypes: [{
      value: ChildrenTextFull,
      name: exports.EFieldTypes.TEXT
    }, {
      value: ChildrenAutoCompleteFull,
      name: exports.EFieldTypes.AUTOCOMPLETE
    }, {
      value: ChildrenDateFull,
      name: exports.EFieldTypes.DATE
    }, {
      value: ChildrenRadioButtonFull,
      name: exports.EFieldTypes.RADIOBUTTON
    }, {
      value: ChildrenCheckboxFull,
      name: exports.EFieldTypes.CHECKBOX
    }, {
      value: ChildrenNumberFul,
      name: exports.EFieldTypes.NUMBER
    }, {
      value: ChildrenMobilePhoneFull,
      name: exports.EFieldTypes.MOBILE_PHONE
    }, {
      value: ChildrenDateRangeFull,
      name: exports.EFieldTypes.DATE_RANGE
    }, {
      value: ChildrenFileFull,
      name: exports.EFieldTypes.FILE
    }, {
      value: ChildrenMultipleAutocompleteFull,
      name: exports.EFieldTypes.MULTIPLE_AUTOCOMPLETE
    }, {
      value: ChildrenArrayFull,
      name: exports.EFieldTypes.ARRAY
    }, {
      value: ChildrenRadioButtonMatrixFull,
      name: exports.EFieldTypes.RADIOBUTTON_MATRIX
    }, {
      value: ChildrenEmptyFull,
      name: exports.EFieldTypes.EMPTY
    }, {
      value: ChildrenSwitchFull,
      name: exports.EFieldTypes.SWITCH
    }, {
      value: ChildrenYesNoRadioButtonFull,
      name: exports.EFieldTypes.YES_NO_RADIOBUTTON
    }]
  }
})], FormGroupFull.prototype, "children", void 0);
var FormV2Full = function FormV2Full() {
  this.formatVersion = void 0;
  this.validationObject = void 0;
  this.crossFieldValidations = void 0;
  this.crossFieldConditions = void 0;
  this.overrides = void 0;
  this.formLayout = void 0;
  this.children = void 0;
  this.submitButtonText = void 0;
  this.cancelButtonText = void 0;
};
tslib.__decorate([classValidator.IsNumber()], FormV2Full.prototype, "formatVersion", void 0);
tslib.__decorate([classTransformer.Type(function () {
  return JsonSchema;
}), classValidator.ValidateNested()], FormV2Full.prototype, "validationObject", void 0);
tslib.__decorate([IsCrossFieldValidations(), IsKeysValid()], FormV2Full.prototype, "crossFieldValidations", void 0);
tslib.__decorate([IsCrossFieldConditions(), IsKeysValid()], FormV2Full.prototype, "crossFieldConditions", void 0);
tslib.__decorate([IsFormOverrides(), IsKeysValid()], FormV2Full.prototype, "overrides", void 0);
tslib.__decorate([IsFormLayout(), IsKeysValid()], FormV2Full.prototype, "formLayout", void 0);
tslib.__decorate([classValidator.IsArray(), classValidator.ValidateNested({
  each: true
}), classTransformer.Type(function (prop) {
  if (prop) {
    var _prop$object16, _prop$object17, _prop$object18, _prop$object19, _prop$object20, _prop$object21, _prop$object22, _prop$object23, _prop$object24, _prop$object25, _prop$object26, _prop$object27, _prop$object28, _prop$object29, _prop$object30, _prop$object31;
    if ((_prop$object16 = prop.object) != null && _prop$object16.children) {
      return FormGroupFull;
    }
    if (((_prop$object17 = prop.object) == null ? void 0 : _prop$object17.type) === exports.EFieldTypes.TEXT) {
      return ChildrenTextFull;
    }
    if (((_prop$object18 = prop.object) == null ? void 0 : _prop$object18.type) === exports.EFieldTypes.AUTOCOMPLETE) {
      return ChildrenAutoCompleteFull;
    }
    if (((_prop$object19 = prop.object) == null ? void 0 : _prop$object19.type) === exports.EFieldTypes.DATE) {
      return ChildrenDateFull;
    }
    if (((_prop$object20 = prop.object) == null ? void 0 : _prop$object20.type) === exports.EFieldTypes.RADIOBUTTON) {
      return ChildrenRadioButtonFull;
    }
    if (((_prop$object21 = prop.object) == null ? void 0 : _prop$object21.type) === exports.EFieldTypes.CHECKBOX) {
      return ChildrenCheckboxFull;
    }
    if (((_prop$object22 = prop.object) == null ? void 0 : _prop$object22.type) === exports.EFieldTypes.NUMBER) {
      return ChildrenNumberFul;
    }
    if (((_prop$object23 = prop.object) == null ? void 0 : _prop$object23.type) === exports.EFieldTypes.MOBILE_PHONE) {
      return ChildrenMobilePhoneFull;
    }
    if (((_prop$object24 = prop.object) == null ? void 0 : _prop$object24.type) === exports.EFieldTypes.DATE_RANGE) {
      return ChildrenDateRangeFull;
    }
    if (((_prop$object25 = prop.object) == null ? void 0 : _prop$object25.type) === exports.EFieldTypes.FILE) {
      return ChildrenFileFull;
    }
    if (((_prop$object26 = prop.object) == null ? void 0 : _prop$object26.type) === exports.EFieldTypes.MULTIPLE_AUTOCOMPLETE) {
      return ChildrenMultipleAutocompleteFull;
    }
    if (((_prop$object27 = prop.object) == null ? void 0 : _prop$object27.type) === exports.EFieldTypes.ARRAY) {
      return ChildrenArrayFull;
    }
    if (((_prop$object28 = prop.object) == null ? void 0 : _prop$object28.type) === exports.EFieldTypes.RADIOBUTTON_MATRIX) {
      return ChildrenRadioButtonMatrixFull;
    }
    if (((_prop$object29 = prop.object) == null ? void 0 : _prop$object29.type) === exports.EFieldTypes.EMPTY) {
      return ChildrenEmptyFull;
    }
    if (((_prop$object30 = prop.object) == null ? void 0 : _prop$object30.type) === exports.EFieldTypes.SWITCH) {
      return ChildrenSwitchFull;
    }
    if (((_prop$object31 = prop.object) == null ? void 0 : _prop$object31.type) === exports.EFieldTypes.YES_NO_RADIOBUTTON) {
      return ChildrenYesNoRadioButtonFull;
    }
  }
  return Object;
}, {
  discriminator: {
    property: 'type',
    subTypes: [{
      value: FormGroupFull,
      name: 'group'
    }, {
      value: ChildrenTextFull,
      name: exports.EFieldTypes.TEXT
    }, {
      value: ChildrenAutoCompleteFull,
      name: exports.EFieldTypes.AUTOCOMPLETE
    }, {
      value: ChildrenDateFull,
      name: exports.EFieldTypes.DATE
    }, {
      value: ChildrenRadioButtonFull,
      name: exports.EFieldTypes.RADIOBUTTON
    }, {
      value: ChildrenCheckboxFull,
      name: exports.EFieldTypes.CHECKBOX
    }, {
      value: ChildrenNumberFul,
      name: exports.EFieldTypes.NUMBER
    }, {
      value: ChildrenMobilePhoneFull,
      name: exports.EFieldTypes.MOBILE_PHONE
    }, {
      value: ChildrenDateRangeFull,
      name: exports.EFieldTypes.DATE_RANGE
    }, {
      value: ChildrenFileFull,
      name: exports.EFieldTypes.FILE
    }, {
      value: ChildrenMultipleAutocompleteFull,
      name: exports.EFieldTypes.MULTIPLE_AUTOCOMPLETE
    }, {
      value: ChildrenArrayFull,
      name: exports.EFieldTypes.ARRAY
    }, {
      value: ChildrenRadioButtonMatrixFull,
      name: exports.EFieldTypes.RADIOBUTTON_MATRIX
    }, {
      value: ChildrenEmptyFull,
      name: exports.EFieldTypes.EMPTY
    }, {
      value: ChildrenSwitchFull,
      name: exports.EFieldTypes.SWITCH
    }, {
      value: ChildrenYesNoRadioButtonFull,
      name: exports.EFieldTypes.YES_NO_RADIOBUTTON
    }]
  }
})], FormV2Full.prototype, "children", void 0);
tslib.__decorate([classValidator.IsString()], FormV2Full.prototype, "submitButtonText", void 0);
tslib.__decorate([classValidator.IsOptional(), classValidator.IsString()], FormV2Full.prototype, "cancelButtonText", void 0);
var Validate = function Validate() {
  this.form = void 0;
};
tslib.__decorate([classTransformer.Type(function () {
  return FormV2Full;
}), classValidator.ValidateNested()], Validate.prototype, "form", void 0);
var validateSchema = function validateSchema(form) {
  try {
    var _form$validationObjec;
    validProperties = Object.keys(form == null || (_form$validationObjec = form.validationObject) == null ? void 0 : _form$validationObjec.properties) || [];
    var validateInstance = classTransformer.plainToClass(Validate, {
      form: cloneDeep__default["default"](form)
    });
    return Promise.resolve(classValidator.validate(validateInstance));
  } catch (e) {
    return Promise.reject(e);
  }
};

exports.FormV2Full = FormV2Full;
exports.buildYupSchema = buildYupSchema;
exports.createErrorObject = createErrorObject;
exports.flattenValues = flattenValues;
exports.formatYupValidationErrors = formatYupValidationErrors;
exports.functionFromString = functionFromString;
exports.getAllFieldNames = getAllFieldNames;
exports.getErrorMessages = getErrorMessages;
exports.getFieldError = getFieldError;
exports.getInitialValues = getInitialValues;
exports.getRuleValueFromSchema = getRuleValueFromSchema;
exports.isFormGroup = isFormGroup;
exports.makeCrossFieldValidation = makeCrossFieldValidation;
exports.parseForm = parseForm;
exports.parseToFormV2 = parseToFormV2;
exports.validateSchema = validateSchema;
exports.validateValues = validateValues;
exports.valuesToDBFormat = valuesToDBFormat;
//# sourceMappingURL=index.js.map
