import { EFieldTypes, ESelectTypes, EnumType, IFormGroupBase, IOption, IRegularBreakpoints } from './modelsCommon';
export interface IRadioButtonMatrixOptions {
    rows: IOption<any>[];
    columns: IOption<any>[];
    grid?: IRegularBreakpoints;
}
export interface ICommonChildrenFull<T extends EnumType> {
    type: EFieldTypes;
    fieldName: T;
    templateId: string;
    disabled?: boolean;
    initialValue: string | null | boolean | number | [null, null] | false;
    fieldTitle?: string;
    fieldSubtitle?: string;
    placeholder?: string;
}
export interface IChildrenTextFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.TEXT;
    initialValue: null;
    multiline?: boolean;
    maxLength?: string;
}
export interface IChildrenAutoCompleteFull<T extends EnumType> extends ICommonChildrenFull<T> {
    loading?: boolean;
    type: EFieldTypes.AUTOCOMPLETE;
    initialValue: null;
    backendOptions?: boolean;
    backendSelectType?: ESelectTypes;
    options: IOption<string>[];
    disabledOptionIds?: number[];
}
export interface IChildrenMobilePhoneFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.MOBILE_PHONE;
    initialValue: string;
    maxLength?: string;
}
export interface IChildrenRadioButtonFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.RADIOBUTTON;
    initialValue: null;
    options: IOption<string>[];
}
export interface IChildrenYesNoRadioButtonFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.YES_NO_RADIOBUTTON;
    initialValue: null;
    options: IOption<boolean>[];
}
export interface IChildrenCheckboxFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.CHECKBOX;
    placeholder: string;
    initialValue: boolean;
}
export interface IChildrenNumberFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.NUMBER;
    initialValue: number;
}
export interface IChildrenDateFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.DATE;
    initialValue: null;
    disableFuture?: boolean;
    disablePast?: boolean;
    minDate?: any;
    helperText: string;
}
export interface IChildrenDateRangeFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.DATE_RANGE;
    initialValue: [null, null];
    disableFuture?: boolean;
    disablePast?: boolean;
    minDate?: any;
    helperText: string;
}
export interface IChildrenFileFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.FILE;
}
export interface IChildrenMultipleAutocompleteFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.MULTIPLE_AUTOCOMPLETE;
}
export interface IChildrenRadioButtonMatrixFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.RADIOBUTTON_MATRIX;
    radioButtonMatrixOptions: IRadioButtonMatrixOptions;
}
export interface IChildrenRatingFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.RATING;
    assessments: {
        [key: number]: string;
    };
}
export interface IChildrenEmptyFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.EMPTY;
}
export interface IChildrenSwitchFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.SWITCH;
}
export interface IChildrenArrayFull<T extends EnumType> extends ICommonChildrenFull<T> {
    type: EFieldTypes.ARRAY;
}
export type IFormFieldFull<T extends EnumType> = ICommonChildrenFull<T> | IChildrenAutoCompleteFull<T> | IChildrenDateFull<T> | IChildrenMobilePhoneFull<T> | IChildrenRadioButtonFull<T> | IChildrenYesNoRadioButtonFull<T> | IChildrenCheckboxFull<T> | IChildrenNumberFull<T> | IChildrenDateRangeFull<T> | IChildrenFileFull<T> | IChildrenMultipleAutocompleteFull<T> | IChildrenRadioButtonMatrixFull<T> | IChildrenEmptyFull<T> | IChildrenSwitchFull<T> | IChildrenArrayFull<T> | IChildrenRatingFull<T>;
export interface IFormGroupFull<T extends EnumType> extends IFormGroupBase<T> {
    title?: string;
    subtitle?: string;
    children: Array<IFormFieldFull<T>>;
}
