export declare enum EFieldTypes {
    TEXT = "text",
    NUMBER = "number",
    SWITCH = "switch",
    DATE = "date",
    DATE_RANGE = "dateRange",
    AUTOCOMPLETE = "autoComplete",
    FILE = "file",
    ARRAY = "array",
    MOBILE_PHONE = "mobilePhone",
    MULTIPLE_AUTOCOMPLETE = "autoCompleteMultiple",
    RADIOBUTTON = "radioButton",
    YES_NO_RADIOBUTTON = "yesNoRadioButton",
    EMPTY = "empty",
    CHECKBOX = "checkbox",
    RADIOBUTTON_MATRIX = "radioButtonMatrix",
    RATING = "rating"
}
export type GridSize = 1 | 2 | 3 | 4 | 6 | 8 | 10 | 12 | 'auto';
export interface IRegularBreakpoints {
    lg?: GridSize;
    md?: GridSize;
    sm?: GridSize;
    xl?: GridSize;
    xs?: GridSize;
}
export interface IOption<T> {
    id: number;
    label: string;
    value: T;
}
export declare enum ESelectTypes {
    COUNTRIES = "countries",
    RELATIONSHIP = "relationship"
}
export type EnumType = string | number | symbol;
export interface IFormFieldBase<T extends EnumType> {
    type: EFieldTypes;
    fieldName: T;
    initialValue?: any;
    templateId?: string;
}
export interface IFormGroupBase<T extends EnumType> {
    title?: string;
    subtitle?: string;
    children: Array<IFormFieldBase<T> | IFormFieldBase<T>>;
}
export type ICrossFieldConditionsParams = {
    required?: string;
    disabled?: string;
    renderCondition?: string;
    disabledCondition?: string;
};
export interface ICrossFieldValidationRule {
    errorKey: string;
    testCondition: string;
    meta?: {
        param: number;
    };
}
export interface IFormSettingsOverrides {
    fieldTitle?: string;
    fieldSubtitle?: string | null;
    initialValue?: any;
    options?: IOption<any>[];
    placeholder?: string;
    helperText?: string;
}
export type ICrossFieldValidations<T extends EnumType> = {
    [key in T]?: ICrossFieldValidationRule[];
};
export type IJsonSchemaProperty = {
    id: number;
    type: 'string' | 'boolean' | 'array' | 'number';
    nullable?: boolean;
    maxLength?: number;
    minLength?: number;
    pattern?: string;
    oneOf?: Array<string | boolean | null>;
    items?: {
        type: 'string';
        format: 'date';
        minLength: number;
        required: boolean;
    };
};
export type IProperty<T extends EnumType> = {
    [key in T]: IJsonSchemaProperty;
};
export interface IJsonSchema<T extends EnumType> {
    $schema: string;
    title: string;
    description: string;
    type: string;
    properties: IProperty<T>;
    required: Array<T>;
}
export interface IValidationError {
    translationKey: string;
    fallbackLanguageTranslation: string;
    meta: {
        [key: string]: any;
    };
}
export interface IValidationErrorField<T extends EnumType> {
    property: T;
    constraints: {
        [key: string]: IValidationError;
    };
}
export type IValidationErrors<T extends EnumType> = {
    [key in T]?: IValidationErrorField<T>;
};
