import 'reflect-metadata';
import { ValidationError } from 'class-validator';
import { EFieldTypes, ESelectTypes, EnumType, ICrossFieldValidationRule, ICrossFieldValidations, IJsonSchema, IOption, IProperty, IRegularBreakpoints } from './modelsCommon';
import { ICrossFieldConditions, IFormLayout, IFormOverrides, IFormV2Full } from './models';
import { IChildrenArrayFull, IChildrenAutoCompleteFull, IChildrenCheckboxFull, IChildrenDateFull, IChildrenDateRangeFull, IChildrenEmptyFull, IChildrenFileFull, IChildrenMobilePhoneFull, IChildrenMultipleAutocompleteFull, IChildrenNumberFull, IChildrenRadioButtonFull, IChildrenRadioButtonMatrixFull, IChildrenSwitchFull, IChildrenTextFull, IChildrenYesNoRadioButtonFull, ICommonChildrenFull, IFormGroupFull, IRadioButtonMatrixOptions } from './inputsModels';
export declare let validProperties: string[];
export declare class Option<T extends EnumType> implements IOption<T> {
    id: number;
    label: string;
    value: T;
}
declare class JsonSchema<T extends EnumType> implements IJsonSchema<T> {
    $schema: string;
    title: string;
    description: string;
    type: string;
    properties: IProperty<T>;
    required: Array<T>;
}
export declare class CrossFieldValidationRule implements ICrossFieldValidationRule {
    errorKey: string;
    testCondition: string;
    meta?: {
        param: number;
    };
    constructor(obj: ICrossFieldValidationRule);
}
export declare class CommonChildrenFull implements ICommonChildrenFull<string> {
    type: EFieldTypes;
    fieldName: string;
    initialValue: string | null | boolean | number | false | [null, null];
    templateId: string;
    fieldTitle?: string;
    fieldSubtitle?: string;
    placeholder?: string;
}
export declare class ChildrenTextFull extends CommonChildrenFull implements IChildrenTextFull<string> {
    multiline?: boolean;
    maxLength?: string;
    type: EFieldTypes.TEXT;
    initialValue: null;
    disabled?: boolean | undefined;
}
export declare class ChildrenAutoCompleteFull extends CommonChildrenFull implements IChildrenAutoCompleteFull<string> {
    backendOptions?: boolean;
    backendSelectType?: ESelectTypes;
    options: IOption<any>[];
    disabledOptionIds?: number[];
    type: EFieldTypes.AUTOCOMPLETE;
    initialValue: null;
    loading?: boolean | undefined;
    disabled?: boolean | undefined;
}
declare class ChildrenMobilePhoneFull extends CommonChildrenFull implements IChildrenMobilePhoneFull<string> {
    type: EFieldTypes.MOBILE_PHONE;
    initialValue: string;
    maxLength?: string;
}
declare class ChildrenRadioButtonFull extends CommonChildrenFull implements IChildrenRadioButtonFull<string> {
    type: EFieldTypes.RADIOBUTTON;
    initialValue: null;
    options: IOption<any>[];
}
declare class ChildrenCheckboxFull extends CommonChildrenFull implements IChildrenCheckboxFull<string> {
    type: EFieldTypes.CHECKBOX;
    placeholder: string;
    initialValue: boolean;
}
declare class ChildrenNumberFul extends CommonChildrenFull implements IChildrenNumberFull<string> {
    type: EFieldTypes.NUMBER;
    initialValue: number;
}
export declare class ChildrenDateFull extends CommonChildrenFull implements IChildrenDateFull<string> {
    disableFuture?: boolean;
    disablePast?: boolean;
    minDate?: any;
    helperText: string;
    type: EFieldTypes.DATE;
    initialValue: null;
}
declare class ChildrenDateRangeFull extends CommonChildrenFull implements IChildrenDateRangeFull<string> {
    type: EFieldTypes.DATE_RANGE;
    initialValue: [null, null];
    disableFuture?: boolean;
    disablePast?: boolean;
    minDate?: any;
    helperText: string;
}
declare class ChildrenFileFull extends CommonChildrenFull implements IChildrenFileFull<string> {
    type: EFieldTypes.FILE;
}
declare class ChildrenMultipleAutocompleteFull extends CommonChildrenFull implements IChildrenMultipleAutocompleteFull<string> {
    type: EFieldTypes.MULTIPLE_AUTOCOMPLETE;
}
declare class ChildrenArrayFull extends CommonChildrenFull implements IChildrenArrayFull<string> {
    type: EFieldTypes.ARRAY;
}
declare class RadioButtonMatrixOptions implements IRadioButtonMatrixOptions {
    rows: IOption<any>[];
    columns: IOption<any>[];
    grid?: IRegularBreakpoints;
}
declare class ChildrenRadioButtonMatrixFull extends CommonChildrenFull implements IChildrenRadioButtonMatrixFull<string> {
    type: EFieldTypes.RADIOBUTTON_MATRIX;
    radioButtonMatrixOptions: RadioButtonMatrixOptions;
}
declare class ChildrenEmptyFull extends CommonChildrenFull implements IChildrenEmptyFull<string> {
    type: EFieldTypes.EMPTY;
}
declare class ChildrenSwitchFull extends CommonChildrenFull implements IChildrenSwitchFull<string> {
    type: EFieldTypes.SWITCH;
}
declare class ChildrenYesNoRadioButtonFull extends CommonChildrenFull implements IChildrenYesNoRadioButtonFull<string> {
    type: EFieldTypes.YES_NO_RADIOBUTTON;
    options: IOption<boolean>[];
    initialValue: null;
}
export declare class FormGroupFull implements IFormGroupFull<string> {
    title?: string;
    subtitle?: string;
    children: Array<ChildrenTextFull | ChildrenAutoCompleteFull | ChildrenDateFull | ChildrenRadioButtonFull | ChildrenCheckboxFull | ChildrenNumberFul | ChildrenMobilePhoneFull | ChildrenDateRangeFull | ChildrenFileFull | ChildrenMultipleAutocompleteFull | ChildrenArrayFull | ChildrenRadioButtonMatrixFull | ChildrenEmptyFull | ChildrenSwitchFull | ChildrenYesNoRadioButtonFull>;
}
export declare class FormV2Full implements IFormV2Full<string> {
    formatVersion: 2;
    validationObject: JsonSchema<string>;
    crossFieldValidations: ICrossFieldValidations<string>;
    crossFieldConditions: ICrossFieldConditions<string>;
    overrides: IFormOverrides<string>;
    formLayout: IFormLayout<string>;
    children: Array<FormGroupFull | ChildrenTextFull | ChildrenAutoCompleteFull | ChildrenDateFull | ChildrenRadioButtonFull | ChildrenCheckboxFull | ChildrenNumberFul | ChildrenMobilePhoneFull | ChildrenDateRangeFull | ChildrenFileFull | ChildrenMultipleAutocompleteFull | ChildrenArrayFull | ChildrenRadioButtonMatrixFull | ChildrenEmptyFull | ChildrenSwitchFull | ChildrenYesNoRadioButtonFull>;
    submitButtonText: string;
    cancelButtonText?: string;
}
export declare const validateSchema: (form: FormV2Full) => Promise<ValidationError[]>;
export {};
