import { ValidationArguments, ValidationOptions, registerDecorator } from 'class-validator';
import { ICrossFieldConditionsParams } from '../modelsCommon';

function isCrossFieldConditionsParamsValid(params: ICrossFieldConditionsParams): boolean {
  if (params.required && typeof params.required !== 'string') {
    return false;
  }
  if (params.disabled && typeof params.disabled !== 'string') {
    return false;
  }
  if (params.renderCondition && typeof params.renderCondition !== 'string') {
    return false;
  }
  if (params.disabledCondition && typeof params.disabledCondition !== 'string') {
    return false;
  }
  return true;
}

export function IsCrossFieldConditions(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'isCrossFieldConditions',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          if (typeof value !== 'object') {
            return false;
          }
          for (const key in value) {
            if (!isCrossFieldConditionsParamsValid(value[key])) {
              return false;
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `${args.property} must be a valid ICrossFieldConditions object.`;
        },
      },
    });
  };
}
