import { ValidationArguments, ValidationOptions, registerDecorator } from 'class-validator';

export function IsCrossFieldValidations(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'isArrayOfType',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          for (const key in value) {
            if (!Array.isArray(value[key])) {
              return false;
            }
            for (const item of args.value[key]) {
              if (
                typeof item.errorKey !== 'string' ||
                typeof item.testCondition !== 'string' ||
                (item.meta !== undefined && typeof item.meta.param !== 'number')
              ) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          const invalidIndexes: string[] = [];
          const invalidInstances: string[] = [];
          for (const key in args.value) {
            if (!Array.isArray(args.value[key])) {
              invalidIndexes.push(key);
            } else {
              for (const item of args.value[key]) {
                if (
                  typeof item.errorKey !== 'string' ||
                  typeof item.testCondition !== 'string' ||
                  (item.meta !== undefined && typeof item.meta.param !== 'number')
                ) {
                  invalidInstances.push(key);
                }
              }
            }
          }
          let message = `${args.property} must be an array`;
          if (invalidIndexes.length > 0) {
            const indexesString = invalidIndexes.join(', ');
            message += `.${indexesString}`;
          }
          if (invalidInstances.length > 0) {
            const instancesString = invalidInstances.join(', ');
            message += ` and ${instancesString} must be instances of CrossFieldValidationRule`;
          }
          return message;
        },
      },
    });
  };
}
