import { registerDecorator, ValidationOptions, ValidationArguments } from 'class-validator';
import { GridSize } from '../modelsCommon';

export function IsFormLayout(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'isFormLayout',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          if (typeof value !== 'object') {
            return false;
          }
          for (const key in value) {
            const breakpoints = value[key];
            if (breakpoints !== null && typeof breakpoints === 'object') {
              if (!isRegularBreakpointsValid(breakpoints)) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `${args.property} must be a valid IFormLayout object.`;
        },
      },
    });
  };
}

function isRegularBreakpointsValid(breakpoints: any): boolean {
  const validGridSizes: (GridSize | undefined)[] = [1, 2, 3, 4, 6, 8, 10, 12, 'auto', undefined];
  for (const key in breakpoints) {
    if (!['lg', 'md', 'sm', 'xl', 'xs'].includes(key)) {
      return false;
    }
    const gridSize = breakpoints[key];
    if (!validGridSizes.includes(gridSize)) {
      return false;
    }
  }
  return true;
}
