import { registerDecorator, ValidationArguments, ValidationOptions } from 'class-validator';
import { validProperties } from '../validate';

export function IsInValidProperties(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'IsInValidProperties',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          return validProperties.includes(value);
        },
        defaultMessage(args: ValidationArguments) {
          return `${args.property} must be included in ${validProperties.join(', ')}.`;
        },
      },
    });
  };
}
