import { ValidationArguments, ValidationOptions, registerDecorator } from 'class-validator';

function isJsonSchemaPropertyValid(property: any): boolean {
  if (property.id === undefined || typeof property.id !== 'number') {
    return false;
  }
  if (property.maxLength !== undefined && typeof property.maxLength !== 'number') {
    return false;
  }
  if (property.minLength !== undefined && typeof property.minLength !== 'number') {
    return false;
  }
  if (property.pattern !== undefined && typeof property.pattern !== 'string') {
    return false;
  }
  if (property.items !== undefined) {
    const items = property.items;
    if (
      typeof items !== 'object' ||
      items.type !== 'string' ||
      items.format !== 'date' ||
      typeof items.minLength !== 'number' ||
      typeof items.required !== 'boolean'
    ) {
      return false;
    }
  }
  return true;
}

export function IsJsonSchemaProperty(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'isJsonSchemaProperty',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          if (typeof value !== 'object') {
            return false;
          }
          for (const key in value) {
            const property = value[key];
            if (property !== null && typeof property === 'object') {
              if (!isJsonSchemaPropertyValid(property)) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `${args.property} must be a valid IJsonSchemaProperty object.`;
        },
      },
    });
  };
}
