import { registerDecorator, ValidationOptions, ValidationArguments } from 'class-validator';
import { validProperties } from '../validate';

export function IsFieldNameValid(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'IsFieldNameValid',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
            if (!validProperties.includes(args.value)) {
              return false;
            }

          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `Value of ${args.property} must be in [${validProperties.join(', ')}]`;
        },
      },
    });
  };
}