import { registerDecorator, ValidationOptions, ValidationArguments } from 'class-validator';

function isFormOverridesValid(override: any): boolean {
  if (override.fieldTitle !== undefined && typeof override.fieldTitle !== 'string') {
    return false;
  }
  if (
    override.fieldSubtitle !== undefined &&
    override.fieldSubtitle !== null &&
    typeof override.fieldSubtitle !== 'string'
  ) {
    return false;
  }
  if (override.options !== undefined && !Array.isArray(override.options)) {
    return false;
  }
  if (override.placeholder !== undefined && typeof override.placeholder !== 'string') {
    return false;
  }
  if (override.helperText !== undefined && typeof override.helperText !== 'string') {
    return false;
  }

  return true;
}

export function IsFormOverrides(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'isFormOverrides',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          if (typeof value !== 'object') {
            return false;
          }
          for (const key in value) {
            const override = value[key];
            if (override !== null && typeof override === 'object') {
              if (!isFormOverridesValid(override)) {
                return false;
              }
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `${args.property} must be a valid IFormOverrides object.`;
        },
      },
    });
  };
}
