import { registerDecorator, ValidationOptions, ValidationArguments } from 'class-validator';
import { validProperties } from '../validate';

export function IsKeysValid(validationOptions?: ValidationOptions) {
  return function (object: Record<string, any>, propertyName: string) {
    registerDecorator({
      name: 'IsKeysValid',
      target: object.constructor,
      propertyName: propertyName,
      options: validationOptions,
      validator: {
        validate(value: any, args: ValidationArguments) {
          if (typeof value !== 'object') {
            return false;
          }

          for (const key in value) {
            if (!validProperties.includes(key)) {
              return false;
            }
          }
          return true;
        },
        defaultMessage(args: ValidationArguments) {
          return `Keys of ${args.property} must be in [${validProperties.join(', ')}]`;
        },
      },
    });
  };
}
