import { IFormFieldFull, IFormGroupFull } from './inputsModels';
import {
  EnumType,
  ICrossFieldConditionsParams,
  ICrossFieldValidations,
  IFormFieldBase,
  IFormGroupBase,
  IFormSettingsOverrides,
  IJsonSchema,
  IRegularBreakpoints,
} from './modelsCommon';
import { IFormParsedFull } from './modelsParsed';

interface IValidationObjectV1<T extends EnumType> extends IJsonSchema<T> {
  crossFieldValidations: ICrossFieldValidations<T>;
}

export interface IFormFieldV1<T extends EnumType> extends IFormFieldBase<T> {
  grid?: IRegularBreakpoints;
  renderCondition?: string;
  disabledCondition?: string;
}

export interface IFormGroupV1<T extends EnumType> extends IFormGroupBase<T> {
  children: Array<IFormFieldV1<T>>;
}

export interface IFormV1<T extends EnumType> {
  formatVersion: 1;
  validationObject: IValidationObjectV1<T>;
  children: Array<IFormFieldV1<T> | IFormGroupV1<T>>;
  submitButtonText: string;
  cancelButtonText?: string;
}

export type ICrossFieldConditions<T extends EnumType> = {
  [key in T]?: ICrossFieldConditionsParams;
};

export type IFormLayout<T extends EnumType> = {
  [key in T]?: IRegularBreakpoints;
};

export type IFormOverrides<T extends EnumType> = {
  [key in T]?: IFormSettingsOverrides;
};

export interface IFormV2<T extends EnumType> {
  formatVersion: 2;
  validationObject: IJsonSchema<T>;
  crossFieldValidations: ICrossFieldValidations<T>;
  crossFieldConditions: ICrossFieldConditions<T>;
  overrides: IFormOverrides<T>;
  formLayout: IFormLayout<T>;
  children: Array<IFormFieldBase<T> | IFormGroupBase<T>>;
  submitButtonText: string;
  cancelButtonText?: string;
}

export interface IFormV2Full<T extends EnumType> extends IFormV2<T> {
  children: Array<IFormFieldFull<T> | IFormGroupFull<T>>;
}

export type IAllForms<T extends EnumType> =
  | IFormV1<T>
  | IFormV2<T>
  | IFormParsedFull<T>
  | IFormV2Full<T>;
